pub struct WasmOptSettings {
pub optimization_passes: OptimizationPasses,
pub keep_debug_symbols: bool,
}Expand description
Settings used when optimizing the Wasm binary using Binaryen’s wasm-opt.
Fields
optimization_passes: OptimizationPassesThe level of optimization used during the wasm-opt run.
keep_debug_symbols: boolWhether or not the Wasm name section should be kept.